package com.jiuqi.xml;

import java.io.IOException;
import java.io.OutputStream;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Stack;

/* loaded from: com_jiuqi_xml.jar:com/jiuqi/xml/XMLWriter.class */
public class XMLWriter {
    private String version;
    private String encoding;
    private String dateFormat;
    private String blank;
    private boolean format;
    private boolean flag;
    private boolean sign;
    private boolean beginLock;
    private boolean attributeLock;
    private boolean valueLock;
    private OutputStream out;
    private Stack tags;
    private int bufferSize;
    private StringBuffer stringBuffer;

    public XMLWriter(OutputStream out) throws XMLException {
        this.version = "1.0";
        this.encoding = "GBK";
        this.dateFormat = "yyyy-MM-dd";
        this.blank = "";
        this.format = true;
        this.flag = false;
        this.sign = false;
        this.beginLock = false;
        this.attributeLock = true;
        this.valueLock = true;
        this.out = null;
        this.tags = new Stack();
        this.bufferSize = 4096;
        this.stringBuffer = new StringBuffer();
        this.out = out;
        init();
    }

    public XMLWriter(OutputStream out, String encoding) throws XMLException {
        this.version = "1.0";
        this.encoding = "GBK";
        this.dateFormat = "yyyy-MM-dd";
        this.blank = "";
        this.format = true;
        this.flag = false;
        this.sign = false;
        this.beginLock = false;
        this.attributeLock = true;
        this.valueLock = true;
        this.out = null;
        this.tags = new Stack();
        this.bufferSize = 4096;
        this.stringBuffer = new StringBuffer();
        this.out = out;
        this.encoding = encoding;
        init();
    }

    public XMLWriter(OutputStream out, String encoding, String version) throws XMLException {
        this.version = "1.0";
        this.encoding = "GBK";
        this.dateFormat = "yyyy-MM-dd";
        this.blank = "";
        this.format = true;
        this.flag = false;
        this.sign = false;
        this.beginLock = false;
        this.attributeLock = true;
        this.valueLock = true;
        this.out = null;
        this.tags = new Stack();
        this.bufferSize = 4096;
        this.stringBuffer = new StringBuffer();
        this.out = out;
        this.encoding = encoding;
        this.version = version;
        init();
    }

    private void init() throws XMLException {
        write("<?xml version=\"");
        write(this.version);
        write("\" encoding=\"");
        write(this.encoding);
        write("\"?");
    }

    public void beginNode(String name) throws XMLException {
        if (this.beginLock) {
            throw new XMLException("开始节点<" + name + ">置于非法位置");
        }
        if (this.format) {
            write(">\n");
            write(this.blank);
            write("<");
            write(name);
            this.blank = String.valueOf(this.blank) + "  ";
        } else {
            write("><");
            write(name);
        }
        this.valueLock = false;
        this.attributeLock = false;
        this.flag = true;
        this.sign = false;
        this.tags.push(name);
    }

    public void setAttribute(String name) throws XMLException {
        setAttribute(name, "");
    }

    public void setAttribute(String name, int value) throws XMLException {
        setAttribute(name, String.valueOf(value));
    }

    public void setAttribute(String name, byte value) throws XMLException {
        setAttribute(name, String.valueOf((int) value));
    }

    public void setAttribute(String name, short value) throws XMLException {
        setAttribute(name, String.valueOf((int) value));
    }

    public void setAttribute(String name, long value) throws XMLException {
        setAttribute(name, String.valueOf(value));
    }

    public void setAttribute(String name, float value) throws XMLException {
        setAttribute(name, String.valueOf(value));
    }

    public void setAttribute(String name, double value) throws XMLException {
        setAttribute(name, String.valueOf(value));
    }

    public void setAttribute(String name, char value) throws XMLException {
        setAttribute(name, String.valueOf(value));
    }

    public void setAttribute(String name, boolean value) throws XMLException {
        setAttribute(name, String.valueOf(value));
    }

    public void setAttribute(String name, Date value) throws XMLException {
        DateFormat df = new SimpleDateFormat(this.dateFormat);
        setAttribute(name, df.format(value));
    }

    public void setAttribute(String name, Object value) throws XMLException {
        setAttribute(name, value.toString());
    }

    public void setAttribute(String name, String value) throws XMLException {
        if (this.attributeLock) {
            throw new XMLException("节点属性 " + name + "=\"" + value + "\" 置于非法位置");
        }
        write(" ");
        write(name);
        write("=\"");
        writeXml(value);
        write("\"");
        this.beginLock = false;
        this.valueLock = false;
    }

    public void setValue() throws XMLException {
        setValue("");
    }

    public void setValue(int value) throws XMLException {
        setValue(String.valueOf(value));
    }

    public void setValue(byte value) throws XMLException {
        setValue(String.valueOf((int) value));
    }

    public void setValue(short value) throws XMLException {
        setValue(String.valueOf((int) value));
    }

    public void setValue(long value) throws XMLException {
        setValue(String.valueOf(value));
    }

    public void setValue(float value) throws XMLException {
        setValue(String.valueOf(value));
    }

    public void setValue(double value) throws XMLException {
        setValue(String.valueOf(value));
    }

    public void setValue(char value) throws XMLException {
        setValue(String.valueOf(value));
    }

    public void setValue(boolean value) throws XMLException {
        setValue(String.valueOf(value));
    }

    public void setValue(Date value) throws XMLException {
        DateFormat df = new SimpleDateFormat(this.dateFormat);
        setValue(df.format(value));
    }

    public void setValue(Object value) throws XMLException {
        setValue(value.toString());
    }

    public void setValue(String value) throws XMLException {
        if (this.valueLock) {
            throw new XMLException("节点内容 " + value + " 置于非法位置");
        }
        write(">");
        writeXml(value);
        this.beginLock = true;
        this.valueLock = true;
        this.attributeLock = true;
        this.sign = true;
    }

    public void setContent(String content) throws XMLException {
        if (this.valueLock) {
            throw new XMLException("节点内容 " + content + " 置于非法位置");
        }
        write(">");
        write("<![CDATA[");
        write(content);
        write("]]>");
        this.beginLock = true;
        this.valueLock = true;
        this.attributeLock = true;
        this.sign = true;
    }

    public void writeContentNode(String name, String content) throws XMLException {
        beginNode(name);
        setContent(content);
        endNode();
    }

    public void endNode() throws XMLException {
        if (this.tags.isEmpty()) {
            throw new XMLException("此结束节点位置不合法，其对应匹配的开始结点未创建");
        }
        if (this.format) {
            this.blank = this.blank.substring(0, this.blank.length() - 2);
        }
        String name = (String) this.tags.pop();
        if (this.flag) {
            if (this.sign) {
                write("</");
                write(name);
            } else {
                write("/");
            }
        } else {
            write(">\n");
            write(this.blank);
            write("</");
            write(name);
        }
        if (this.tags.empty()) {
            writeEnd(">");
        }
        this.flag = false;
        this.valueLock = true;
        this.beginLock = false;
        this.attributeLock = true;
    }

    public void writeNode(String name) throws XMLException {
        beginNode(name);
        endNode();
    }

    public void writeNode(String name, String value) throws XMLException {
        beginNode(name);
        setValue(value);
        endNode();
    }

    private void write(String str) throws XMLException {
        if (str == null) {
            throw new XMLException("不允许在XML中写入NULL值");
        }
        this.stringBuffer.append(str);
        if (this.stringBuffer.length() > this.bufferSize) {
            flush();
        }
    }

    private void writeXml(String str) throws XMLException {
        if (str == null) {
            throw new XMLException("不允许在XML中写入NULL值");
        }
        for (int i = 0; i < str.length(); i++) {
            if (str.charAt(i) == '\"') {
                write("&quot;");
            } else if (str.charAt(i) == '\'') {
                write("&apos;");
            } else if (str.charAt(i) == '&') {
                write("&amp;");
            } else if (str.charAt(i) == '<') {
                write("&lt;");
            } else if (str.charAt(i) == '>') {
                write("&gt;");
            } else {
                write(str.substring(i, i + 1));
            }
        }
    }

    private void writeEnd(String str) throws XMLException {
        this.stringBuffer.append(str);
        flush();
    }

    public void flush() throws XMLException {
        try {
            this.out.write(this.stringBuffer.toString().getBytes(this.encoding));
            this.stringBuffer.delete(0, this.stringBuffer.length());
        } catch (IOException e) {
            throw new XMLException(e);
        }
    }

    public boolean isFormat() {
        return this.format;
    }

    public void setFormat(boolean format) {
        this.format = format;
    }

    public String getDateFormat() {
        return this.dateFormat;
    }

    public void setDateFormat(String dateFormat) {
        this.dateFormat = dateFormat;
    }

    public int getBufferSize() {
        return this.bufferSize;
    }

    public void setBufferSize(int bufferSize) {
        this.bufferSize = bufferSize;
    }
}
